<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * News Manager cache functions.
 */


/*******************************************************
 * @function nm_update_cache
 * @action store frequently accessed post data in cache files
 */
function nm_update_cache() {
  list($posts, $archives, $tags) = nm_get_cache_data();
  $status = nm_posts_to_xml($posts, NMPOSTCACHE) &&
            nm_array_to_xml($archives, NMARCHIVECACHE) &&
            nm_array_to_xml($tags, NMTAGCACHE);
  return $status;
}


/*******************************************************
 * @function nm_get_cache_data
 * @return arrays with relevant post data
 */
function nm_get_cache_data() {
  $posts = $archives = $tags = array();
  $files = getFiles(NMPOSTPATH);
  # collect all post data
  foreach ($files as $file) {
    if (isFile($file, NMPOSTPATH, 'xml')) {
      $data = getXML(NMPOSTPATH . $file);
      $time = strtotime($data->date);
      $posts[$time]['slug'] = basename($file, '.xml');
      $posts[$time]['title'] = strval($data->title);
      $posts[$time]['date'] = strval($data->date);
      $posts[$time]['tags'] = strval($data->tags);
      $posts[$time]['private'] = strval($data->private);
    }
  }
  krsort($posts);
  # collect archive and tag data
  foreach ($posts as $post) {
    if ($post['private'] != 'Y') {
      $archive = date('Ym', strtotime($post['date']));
      $archives[$archive][] = $post['slug'];
      if (!empty($post['tags'])) {
        foreach (explode(',', $post['tags']) as $tag)
          $tags[$tag][] = $post['slug'];
      }
    }
  }
  ksort($tags);
  # return post-, archive- and tag arrays
  return array($posts, $archives, $tags);
}


/*******************************************************
 * @function nm_posts_to_xml
 * @action write post data to xml file
 */
function nm_posts_to_xml($posts, $file) {
  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><channel></channel>');
  foreach ($posts as $post) {
    $elem = $xml->addChild('item');
    $elem->addChild('slug', $post['slug']);
    $elem->addChild('title', $post['title']);
    $elem->addChild('date', $post['date']);
    $elem->addChild('tags', $post['tags']);
    $elem->addChild('private', $post['private']);
  }
  return @XMLsave($xml, $file);
}


/*******************************************************
 * @function nm_array_to_xml
 * @action write archive or tag data to xml file
 */
function nm_array_to_xml($data, $file) {
  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><channel></channel>');
  foreach ($data as $item=>$posts) {
    $elem = $xml->addChild('item');
    $elem->addChild('id', $item);
    $elem->addChild('posts', implode(',', $posts));
  }
  return @XMLsave($xml, $file);
}


?>
